@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2010  See the AUTHORS file for details.
+ * Copyright (C) 2004-2011  See the AUTHORS file for details.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 as published
@@ -9,6 +9,7 @@
 #ifndef _USER_H
 #define _USER_H
 
+#include "zncconfig.h"
 #include "Buffer.h"
 #include "FileUtils.h"
 #include "Modules.h"
@@ -53,7 +54,6 @@ public:
 	bool AddChan(const CString& sName, bool bInConfig);
 	bool DelChan(const CString& sName);
 	void JoinChans();
-	bool JoinChan(CChan* pChan);
 	CServer* FindServer(const CString& sName) const;
 	bool DelServer(const CString& sName, unsigned short uPort, const CString& sPass);
 	bool AddServer(const CString& sName);
@@ -68,7 +68,6 @@ public:
 	static bool IsValidUserName(const CString& sUserName);
 	static CString MakeCleanUserName(const CString& sUserName);
 	bool IsLastServer() const;
-	bool ConnectPaused();
 
 	void DelClients();
 	void DelServers();
@@ -102,6 +101,7 @@ public:
 	bool PutStatus(const CString& sLine, CClient* pClient = NULL, CClient* pSkipClient = NULL);
 	bool PutStatusNotice(const CString& sLine, CClient* pClient = NULL, CClient* pSkipClient = NULL);
 	bool PutModule(const CString& sModule, const CString& sLine, CClient* pClient = NULL, CClient* pSkipClient = NULL);
+	bool PutModNotice(const CString& sModule, const CString& sLine, CClient* pClient = NULL, CClient* pSkipClient = NULL);
 
 	bool IsUserAttached() const { return !m_vClients.empty(); }
 	void UserConnected(CClient* pClient);
@@ -109,8 +109,8 @@ public:
 
 	CString GetLocalIP();
 	CString GetLocalDCCIP();
-	bool IsIRCConnected() const { return GetIRCSock() != NULL; }
-	void IRCConnected(CIRCSock* pIRCSock);
+	bool IsIRCConnected() const;
+	void SetIRCSocket(CIRCSock* pIRCSock);
 	void IRCDisconnected();
 	void CheckIRCConnect();
 
@@ -136,7 +136,6 @@ public:
 	void AddBytesWritten(unsigned long long u) { m_uBytesWritten += u; }
 
 	// Setters
-	void SetUserName(const CString& s);
 	void SetNick(const CString& s);
 	void SetAltNick(const CString& s);
 	void SetIdent(const CString& s);
@@ -156,6 +155,7 @@ public:
 	void SetIRCServer(const CString& s);
 	void SetQuitMsg(const CString& s);
 	bool AddCTCPReply(const CString& sCTCP, const CString& sReply);
+	bool DelCTCPReply(const CString& sCTCP);
 	bool SetBufferCount(unsigned int u, bool bForce = false);
 	void SetKeepBuffer(bool b);
 	void SetChanPrefixes(const CString& s) { m_sChanPrefixes = s; }
@@ -225,10 +225,12 @@ public:
 	CString GetSkinName() const;
 	// !Getters
 private:
+	bool JoinChan(CChan* pChan);
+	void JoinChans(set<CChan*>& sChans);
+
 protected:
-	time_t                m_uConnectTime;
-	CString               m_sUserName;
-	CString               m_sCleanUserName;
+	const CString         m_sUserName;
+	const CString         m_sCleanUserName;
 	CString               m_sNick;
 	CString               m_sAltNick;
 	CString               m_sIdent;
